Title: Matching Adjusted Indirect Comparison
Package: maicplus
Version: 0.1.2
Authors@R: c(
   person(
      given = "Gregory",
      family = "Chen",
      role = c("aut"),
      email = "xiangyi.gregory.chen@msd.com"
      ),
   person(
      given = "Michael",
      family = "Seo",
      role = c("aut"),
      email = "michael.seo@roche.com"
      ),
   person(
      given = "Isaac",
      family = "Gravestock",
      role = c("aut", "cre"),
      email = "isaac.gravestock@roche.com"
      ),
   person(
      given = "Miranta",
      family = "Antoniou",
      role = c("ctb"),
      email = "miranta.antoniou@roche.com"
      ),
   person(
      given = "Chrysostomos",
      family = "Kalyvas",
      role = c("ctb"),
      email = "chrysostomos.kal@gmail.com"
   ),
   person("MSD, Inc.", role = c("cph", "fnd")),
   person("F. Hoffmann-La Roche AG", role = c("cph", "fnd"))
   )
Description: Facilitates performing matching adjusted indirect comparison
 (MAIC) analysis where the endpoint of interest is either time-to-event
 (e.g. overall survival) or binary (e.g. objective tumor response). The method
 is described by Signorovitch et al (2012) <doi:10.1016/j.jval.2012.05.004>.
License: Apache License 2.0
URL: https://github.com/hta-pharma/maicplus/,
        https://hta-pharma.github.io/maicplus/
BugReports: https://github.com/hta-pharma/maicplus/issues
Depends: R (>= 4.1)
Imports: graphics, grDevices, stats, survival, lubridate, matrixStats,
        MASS, boot, stringr, lmtest, sandwich
Suggests: knitr, testthat (>= 2.0), ggplot2, rmarkdown, dplyr,
        survminer, flexsurv, tibble, vdiffr, checkmate
VignetteBuilder: knitr
biocViews:
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.2
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2025-02-21 14:57:33 UTC; root
Author: Gregory Chen [aut],
  Michael Seo [aut],
  Isaac Gravestock [aut, cre],
  Miranta Antoniou [ctb],
  Chrysostomos Kalyvas [ctb],
  MSD, Inc. [cph, fnd],
  F. Hoffmann-La Roche AG [cph, fnd]
Maintainer: Isaac Gravestock <isaac.gravestock@roche.com>
Repository: CRAN
Date/Publication: 2025-02-21 16:00:02 UTC
Built: R 4.6.0; ; 2026-04-28 06:17:16 UTC; unix
