# Generated by roxygen2: do not edit by hand

S3method(plot,maicplus_estimate_weights)
S3method(print,maicplus_bucher)
S3method(print,maicplus_check_weights)
export(basic_kmplot)
export(basic_kmplot2)
export(bucher)
export(calculate_weights_legend)
export(center_ipd)
export(check_weights)
export(dummize_ipd)
export(estimate_weights)
export(find_SE_from_CI)
export(get_pseudo_ipd_binary)
export(get_time_as)
export(get_time_conversion)
export(glm_makeup)
export(kmplot)
export(kmplot2)
export(maic_anchored)
export(maic_unanchored)
export(medSurv_makeup)
export(ph_diagplot)
export(ph_diagplot_lch)
export(ph_diagplot_schoenfeld)
export(plot_weights_base)
export(plot_weights_ggplot)
export(process_agd)
export(set_time_conversion)
export(survfit_makeup)
import(MASS)
import(boot)
import(graphics)
import(lubridate)
import(stats)
import(stringr)
import(survival)
importFrom(boot,boot)
importFrom(boot,boot.ci)
importFrom(grDevices,col2rgb)
importFrom(grDevices,rgb)
importFrom(lmtest,coefci)
importFrom(lmtest,coeftest)
importFrom(matrixStats,weightedMedian)
importFrom(sandwich,vcovHC)
importFrom(survival,Surv)
importFrom(survival,coxph)
importFrom(survival,survfit)
importFrom(utils,stack)
